@@ -1,16 +1,16 @@
 from typing import List, Optional, Dict
-from datasets import load_dataset
-import pandas as pd
 from tqdm import tqdm
 from typing import Union
 
 from deepeval.dataset import Golden
-from deepeval.benchmarks.base_benchmark import DeepEvalBaseBenchmark
+from deepeval.benchmarks.base_benchmark import (
+    DeepEvalBaseBenchmark,
+    DeepEvalBaseBenchmarkResult,
+)
 from deepeval.models import DeepEvalBaseLLM
 from deepeval.benchmarks.drop.task import DROPTask
 from deepeval.benchmarks.drop.template import DROPTemplate
 from deepeval.benchmarks.utils import should_use_batch
-from deepeval.scorer import Scorer
 from deepeval.benchmarks.schema import (
     DROPDateSchema,
     DROPNumberSchema,
@@ -30,6 +30,9 @@ class DROP(DeepEvalBaseBenchmark):
         verbose_mode: bool = False,
         **kwargs,
     ):
+        from deepeval.scorer import Scorer
+        import pandas as pd
+
         assert n_shots <= 5, "DROP only supports n_shots <= 5"
         super().__init__(**kwargs)
         self.tasks: List[DROPTask] = list(DROPTask) if tasks is None else tasks
@@ -44,8 +47,14 @@ class DROP(DeepEvalBaseBenchmark):
         self.verbose_mode: bool = verbose_mode
 
     def evaluate(
-        self, model: DeepEvalBaseLLM, batch_size: Optional[int] = None
-    ) -> Dict:
+        self,
+        model: DeepEvalBaseLLM,
+        *args,
+        batch_size: int | None = None,
+        **kwargs,
+    ) -> DeepEvalBaseBenchmarkResult:
+        import pandas as pd
+
         with capture_benchmark_run("DROP", len(self.tasks)):
             overall_correct_predictions = 0
             overall_total_predictions = 0
@@ -149,7 +158,9 @@ class DROP(DeepEvalBaseBenchmark):
             )
             self.overall_score = overall_accuracy
 
-            return overall_accuracy
+            return DeepEvalBaseBenchmarkResult(
+                overall_accuracy=overall_accuracy
+            )
 
     def predict(self, model: DeepEvalBaseLLM, golden: Golden) -> Dict:
         # Define prompt template
@@ -251,11 +262,13 @@ class DROP(DeepEvalBaseBenchmark):
         return res
 
     def load_benchmark_dataset(self, task: DROPTask) -> List[Golden]:
+        from datasets import load_dataset
+
         # cache dataset
         if self.dataset:
             dataset = self.dataset
         else:
-            dataset = load_dataset("ucinlp/drop", trust_remote_code=True)
+            dataset = load_dataset("ucinlp/drop")
             self.dataset = dataset
 
         # construct example dataset
