@@ -1,17 +1,16 @@
 from typing import List, Dict, Optional
-from datasets import load_dataset, Dataset
 from tqdm import tqdm
-import pandas as pd
-from typing import Union
 
 from deepeval.dataset import Golden
-from deepeval.benchmarks.base_benchmark import DeepEvalBaseBenchmark
+from deepeval.benchmarks.base_benchmark import (
+    DeepEvalBaseBenchmark,
+    DeepEvalBaseBenchmarkResult,
+)
 from deepeval.models import DeepEvalBaseLLM
 from deepeval.benchmarks.truthful_qa.task import TruthfulQATask
 from deepeval.benchmarks.truthful_qa.mode import TruthfulQAMode
 from deepeval.benchmarks.truthful_qa.template import TruthfulQATemplate
 from deepeval.benchmarks.utils import should_use_batch
-from deepeval.scorer import Scorer
 from deepeval.benchmarks.schema import NumberSchema, ListOfNumbersSchema
 from deepeval.telemetry import capture_benchmark_run
 
@@ -33,6 +32,10 @@ class TruthfulQA(DeepEvalBaseBenchmark):
         ] = None,
         **kwargs,
     ):
+        from deepeval.scorer import Scorer
+        import pandas as pd
+        from datasets import Dataset
+
         super().__init__(**kwargs)
         self.tasks: List[TruthfulQATask] = (
             list(TruthfulQATask) if tasks is None else tasks
@@ -53,8 +56,14 @@ class TruthfulQA(DeepEvalBaseBenchmark):
             self.confinement_instructions_dict = confinement_instructions_dict
 
     def evaluate(
-        self, model: DeepEvalBaseLLM, batch_size: Optional[int] = None
-    ) -> Dict:
+        self,
+        model: DeepEvalBaseLLM,
+        *args,
+        batch_size: int | None = None,
+        **kwargs,
+    ) -> DeepEvalBaseBenchmarkResult:
+        import pandas as pd
+
         with capture_benchmark_run("TruthfulQA", len(self.tasks)):
             overall_correct_predictions = 0
             overall_total_predictions = 0
@@ -92,7 +101,13 @@ class TruthfulQA(DeepEvalBaseBenchmark):
                                 task_correct_predictions += 1
                                 overall_correct_predictions += 1
                             predictions_row.append(
-                                (task.value, golden.input, prediction, score)
+                                (
+                                    task.value,
+                                    golden.input,
+                                    prediction,
+                                    golden.expected_output,
+                                    score,
+                                )
                             )
                 else:
                     for idx, golden in enumerate(
@@ -154,7 +169,9 @@ class TruthfulQA(DeepEvalBaseBenchmark):
             )
             self.overall_score = overall_accuracy
 
-            return overall_accuracy
+            return DeepEvalBaseBenchmarkResult(
+                overall_accuracy=overall_accuracy
+            )
 
     def predict(
         self, model: DeepEvalBaseLLM, golden: Golden, mode: TruthfulQAMode
@@ -177,7 +194,7 @@ class TruthfulQA(DeepEvalBaseBenchmark):
                 )
                 prediction = str(res.answer)
 
-        except TypeError:
+        except (TypeError, ValueError, AttributeError):
             prompt += self.confinement_instructions_dict[mode]
             prediction = model.generate(prompt)
 
@@ -225,7 +242,7 @@ class TruthfulQA(DeepEvalBaseBenchmark):
                 )
                 predictions = [str(res.answer) for res in responses]
 
-        except TypeError:
+        except (TypeError, ValueError, AttributeError):
             if mode == TruthfulQAMode.MC1:
                 prompts = [
                     prompt
@@ -266,6 +283,9 @@ class TruthfulQA(DeepEvalBaseBenchmark):
     def load_benchmark_dataset(
         self, task: TruthfulQATask, mode: TruthfulQAMode
     ) -> List[Golden]:
+        from datasets import load_dataset, Dataset
+        import pandas as pd
+
         # Load full dataset
         if self.mc_dataset is None:
             gen_dataset = load_dataset("truthful_qa", "generation")[
@@ -289,7 +309,7 @@ class TruthfulQA(DeepEvalBaseBenchmark):
             lambda data: data["category"] == task.value
         )
 
-        # Create goldens list from datset
+        # Create goldens list from dataset
         goldens: List[Golden] = []
         for data in dataset:
             if mode == TruthfulQAMode.MC1:
