@@ -1,4 +1,4 @@
-from typing import List, Optional
+from typing import List, Optional, Literal
 from pydantic import BaseModel, Field
 
 
@@ -8,7 +8,7 @@ class Opinions(BaseModel):
 
 # BiasMetric runs a similar algorithm to Dbias: https://arxiv.org/pdf/2208.05777.pdf
 class BiasVerdict(BaseModel):
-    verdict: str
+    verdict: Literal["yes", "no"]
     reason: Optional[str] = Field(default=None)
 
 
@@ -16,5 +16,5 @@ class Verdicts(BaseModel):
     verdicts: List[BiasVerdict]
 
 
-class Reason(BaseModel):
+class BiasScoreReason(BaseModel):
     reason: str
