@@ -6,14 +6,14 @@ class Statements(BaseModel):
     statements: List[str]
 
 
-class AnswerRelvancyVerdict(BaseModel):
+class AnswerRelevancyVerdict(BaseModel):
     verdict: str
     reason: Optional[str] = Field(default=None)
 
 
 class Verdicts(BaseModel):
-    verdicts: List[AnswerRelvancyVerdict]
+    verdicts: List[AnswerRelevancyVerdict]
 
 
-class Reason(BaseModel):
+class MultimodelAnswerRelevancyScoreReason(BaseModel):
     reason: str
